pub enum AuthCommand {
Init {
owner_key: Option<PathBuf>,
force: bool,
no_passphrase: bool,
keychain: bool,
},
Status {
owner_key: Option<PathBuf>,
node_key: Option<PathBuf>,
node_ownership: Option<PathBuf>,
trust_store: Option<PathBuf>,
},
SignNode {
owner_key: Option<PathBuf>,
node_key: Option<PathBuf>,
out: Option<PathBuf>,
hostname_hint: Option<String>,
node_label: Option<String>,
expires_in_hours: u64,
},
RenewNode {
owner_key: Option<PathBuf>,
node_key: Option<PathBuf>,
out: Option<PathBuf>,
hostname_hint: Option<String>,
node_label: Option<String>,
expires_in_hours: u64,
},
VerifyNode {
file: Option<PathBuf>,
node_id: Option<String>,
trust_store: Option<PathBuf>,
trust_policy: Option<TrustPolicy>,
},
RotateNode {
owner_key: Option<PathBuf>,
node_key: Option<PathBuf>,
out: Option<PathBuf>,
hostname_hint: Option<String>,
node_label: Option<String>,
expires_in_hours: u64,
revoke_current: bool,
reason: Option<String>,
trust_store: Option<PathBuf>,
},
RevokeOwner {
owner_id: String,
reason: Option<String>,
trust_store: Option<PathBuf>,
},
RevokeNode {
cert_id: Option<String>,
node_id: Option<String>,
reason: Option<String>,
trust_store: Option<PathBuf>,
},
RotateOwner {
owner_key: Option<PathBuf>,
no_passphrase: bool,
force: bool,
},
Trust {
command: TrustCommand,
},
}Variants
Init
Generate a new owner keypair and save to keystore.
Fields
Status
Show current owner identity status.
Fields
SignNode
Sign the current node identity with the existing owner keystore.
Fields
RenewNode
Renew the local node ownership certificate in place.
Fields
VerifyNode
Verify a node ownership certificate.
Fields

trust_policy: Option<TrustPolicy>Override trust policy used for verification.
RotateNode
Rotate the local node identity key.
Fields
RevokeOwner
Revoke an owner in the local trust store.
Fields
RevokeNode
Revoke a node certificate or node ID in the local trust store.
Fields
RotateOwner
Rotate the existing owner keystore identity.
Fields
Trust
Manage the local trust store.
Fields

command: TrustCommandTrait Implementations
Sourceimpl Debug for AuthCommand
impl Debug for AuthCommand
Sourceimpl FromArgMatches for AuthCommand
impl FromArgMatches for AuthCommand
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Subcommand for AuthCommand
impl Subcommand for AuthCommand
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for AuthCommand
impl RefUnwindSafe for AuthCommand
impl Send for AuthCommand
impl Sync for AuthCommand
impl Unpin for AuthCommand
impl UnsafeUnpin for AuthCommand
impl UnwindSafe for AuthCommand