pub enum TrustCommand {
Add {
owner_id: String,
label: Option<String>,
trust_store: Option<PathBuf>,
},
Remove {
owner_id: String,
trust_store: Option<PathBuf>,
},
List {
trust_store: Option<PathBuf>,
},
}Variants
Add
Add an owner to the local trust store allowlist.
Fields
Remove
Remove an owner from the local trust store allowlist.
Fields
List
Show the current trust store contents.