RuntimeCommand

Enum RuntimeCommand 

pub enum RuntimeCommand {
Show 17 variants List { available: bool, installed: bool, manifest: Option<PathBuf>, bundle_dirs: Vec<PathBuf>, cache_dir: Option<PathBuf>, json: bool, }, Install { runtime: Option<String>, manifest: Option<PathBuf>, bundle_dirs: Vec<PathBuf>, cache_dir: Option<PathBuf>, json: bool, }, Remove { native_runtime_id: String, mesh_version: Option<String>, cache_dir: Option<PathBuf>, json: bool, }, Prune { active_only: bool, mesh_version: Option<String>, cache_dir: Option<PathBuf>, json: bool, }, Status { port: u16, }, Bootstrap { port: u16, json: bool, }, GetConfig { endpoint: String, port: u16, json: bool, }, ScanRefresh { endpoint: String, port: u16, json: bool, }, LoadModel { endpoint: String, model: String, profile: Option<String>, port: u16, json: bool, }, UnloadModel { endpoint: String, model: Option<String>, instance_id: Option<String>, port: u16, json: bool, }, EnsureModel { endpoint: String, model: String, profile: Option<String>, port: u16, json: bool, }, DrainModel { endpoint: String, model: Option<String>, instance_id: Option<String>, port: u16, json: bool, }, RefreshInventory { endpoint: String, port: u16, json: bool, }, ApplyConfig { endpoint: String, expected_revision: u64, config: PathBuf, port: u16, json: bool, }, Load { name: String, port: u16, }, Unload { name: String, port: u16, }, Guardrails { mode: MeshGuardrailCliMode, port: u16, json: bool, },
}

Variants



List

List available or locally discoverable native runtimes.

Fields

available: bool

List release-manifest or bundled runtimes instead of installed runtimes.

installed: bool

List locally discoverable native runtimes. This is the default.

manifest: Option<PathBuf>

Release manifest JSON to inspect.

bundle_dirs: Vec<PathBuf>

Packaged native runtime directory to inspect. Repeatable.

cache_dir: Option<PathBuf>

Override the native runtime cache root.

json: bool

Print machine-readable JSON.



Install

Install the recommended native runtime, or an explicit flavor/runtime ID.

Fields

runtime: Option<String>

Optional runtime flavor or native runtime ID. Omit to install the recommended runtime.

manifest: Option<PathBuf>

Release manifest JSON to resolve against.

bundle_dirs: Vec<PathBuf>

Packaged native runtime directory to install from. Repeatable.

cache_dir: Option<PathBuf>

Override the native runtime cache root.

json: bool

Print machine-readable JSON.



Remove

Remove an installed native runtime.

Fields

native_runtime_id: String

Native runtime ID to remove.

mesh_version: Option<String>

MeshLLM version. Defaults to the running MeshLLM version.

cache_dir: Option<PathBuf>

Override the native runtime cache root.

json: bool

Print machine-readable JSON.



Prune

Prune old native runtimes from the cache.

Fields

active_only: bool

Remove every runtime not matching the active MeshLLM version.

mesh_version: Option<String>

Override the active MeshLLM version. Defaults to the running version.

cache_dir: Option<PathBuf>

Override the native runtime cache root.

json: bool

Print machine-readable JSON.



Status

Show local model status on a running mesh-llm instance.

Fields

port: u16

Console/API port of the running mesh-llm instance (default: 3131)



Bootstrap

Show the local-only owner-control bootstrap policy for a running mesh-llm instance.

Fields

port: u16

Console/API port of the running mesh-llm instance (default: 3131)

json: bool

Print the raw JSON payload.



GetConfig

Fetch config from a remote owner-control endpoint through the local management API.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print the raw JSON payload.



ScanRefresh

Scan and refresh inventory on a remote owner-control endpoint.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print the raw JSON payload.



LoadModel

Load a model on a remote node through owner-control.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

model: String

Model canonical reference to load.

profile: Option<String>

Optional runtime profile to apply.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print machine-readable JSON.



UnloadModel

Unload a model on a remote node through owner-control.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

model: Option<String>

Model canonical reference to unload.

instance_id: Option<String>

Exact instance ID to unload.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print machine-readable JSON.



EnsureModel

Ensure a model is loaded on a remote node through owner-control.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

model: String

Model canonical reference to ensure loaded.

profile: Option<String>

Optional runtime profile to maintain.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print machine-readable JSON.



DrainModel

Drain and unload a model on a remote node through owner-control.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

model: Option<String>

Model canonical reference to drain.

instance_id: Option<String>

Exact instance ID to drain.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print machine-readable JSON.



RefreshInventory

Refresh local inventory on a remote owner-control endpoint through the local management API.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print the raw JSON payload.



ApplyConfig

Apply config to a remote owner-control endpoint through the local management API.

Fields

endpoint: String

Explicit owner-control endpoint token for the target node.

expected_revision: u64

Expected remote config revision for CAS.

config: PathBuf

TOML config file to apply remotely.

port: u16

Console/API port of the local mesh-llm instance (default: 3131)

json: bool

Print the raw JSON payload.



Load

Load a local model into a running mesh-llm instance.

Fields

name: String

Model name/path/url to load

port: u16

Console/API port of the running mesh-llm instance (default: 3131)



Unload

Unload a local model from a running mesh-llm instance.

Fields

name: String

Model name to unload

port: u16

Console/API port of the running mesh-llm instance (default: 3131)



Guardrails

Set mesh guardrail mode on running Skippy-backed models without restart.

Fields

mode: MeshGuardrailCliMode

Guardrail mode to apply to active Skippy-backed OpenAI surfaces.

port: u16

Console/API port of the running mesh-llm instance (default: 3131)

json: bool

Print the raw JSON payload.