pub enum ModelsCommand {
Package {Show 17 fields
source_repo: Option<String>,
quant: Option<String>,
target: Option<String>,
model_id: Option<String>,
flavor: String,
timeout: String,
mesh_llm_ref: String,
experimental: bool,
dry_run: bool,
confirm: bool,
follow: bool,
status: Option<String>,
logs: Option<String>,
cancel: Option<String>,
list: bool,
update_script: bool,
json: bool,
},
Recommended {
json: bool,
},
Installed {
json: bool,
},
Cleanup {
unused_since: Option<String>,
yes: bool,
json: bool,
},
Prune {
yes: bool,
json: bool,
},
Certify {
model: String,
report_out: Option<PathBuf>,
json: bool,
package_only: bool,
api_base: Option<String>,
prompt: String,
max_tokens: u32,
},
List {
json: bool,
},
Search {
query: Vec<String>,
gguf: bool,
mlx: bool,
catalog: bool,
limit: usize,
sort: ModelSearchSort,
json: bool,
},
Show {
model: String,
json: bool,
},
Download {
model: String,
draft: bool,
direct: bool,
json: bool,
},
Updates {
repo: Option<String>,
all: bool,
check: bool,
json: bool,
},
Delete {
model: String,
yes: bool,
json: bool,
},
}Variants
Package
Package a GGUF model for distributed inference by splitting it into layer files on Hugging Face Jobs.
Fields
source_repo: Option<String>Source Hugging Face model ref (e.g. unsloth/Qwen3-235B-A22B-GGUF:UD-Q4_K_XL).
Recommended
List recommended models from the remote meshllm/catalog.
Installed
List installed local models from the HF cache.
Cleanup
Preview or remove mesh-managed models from the Hugging Face cache.
Fields
Prune
Remove stale derived skippy stage artifacts from the mesh cache.
Certify
Certify a Skippy layer package can be resolved, verified, and smoke-tested.
Fields
model: StringExact layer package ref, local package dir, or catalog model ref with a package mapping.
List
List remote catalog models.
Search
Search for catalog models and downloadable GGUF/MLX artifacts on Hugging Face.
Fields
sort: ModelSearchSortSort search results.
Show
Show details for one exact model reference.
Download
Download one exact model reference.
Fields
Updates
Check or refresh cached Hugging Face repos.
Fields
Delete
Delete a specific model from local storage.