pub enum RuntimeCommand {
Show 17 variants
List {
available: bool,
installed: bool,
manifest: Option<PathBuf>,
bundle_dirs: Vec<PathBuf>,
cache_dir: Option<PathBuf>,
json: bool,
},
Install {
runtime: Option<String>,
manifest: Option<PathBuf>,
bundle_dirs: Vec<PathBuf>,
cache_dir: Option<PathBuf>,
json: bool,
},
Remove {
native_runtime_id: String,
mesh_version: Option<String>,
cache_dir: Option<PathBuf>,
json: bool,
},
Prune {
active_only: bool,
mesh_version: Option<String>,
cache_dir: Option<PathBuf>,
json: bool,
},
Status {
port: u16,
},
Bootstrap {
port: u16,
json: bool,
},
GetConfig {
endpoint: String,
port: u16,
json: bool,
},
ScanRefresh {
endpoint: String,
port: u16,
json: bool,
},
LoadModel {
endpoint: String,
model: String,
profile: Option<String>,
port: u16,
json: bool,
},
UnloadModel {
endpoint: String,
model: Option<String>,
instance_id: Option<String>,
port: u16,
json: bool,
},
EnsureModel {
endpoint: String,
model: String,
profile: Option<String>,
port: u16,
json: bool,
},
DrainModel {
endpoint: String,
model: Option<String>,
instance_id: Option<String>,
port: u16,
json: bool,
},
RefreshInventory {
endpoint: String,
port: u16,
json: bool,
},
ApplyConfig {
endpoint: String,
expected_revision: u64,
config: PathBuf,
port: u16,
json: bool,
},
Load {
name: String,
port: u16,
},
Unload {
name: String,
port: u16,
},
Guardrails {
mode: MeshGuardrailCliMode,
port: u16,
json: bool,
},
}Variants
List
List available or locally discoverable native runtimes.
Fields
Install
Install the recommended native runtime, or an explicit flavor/runtime ID.
Fields
Remove
Remove an installed native runtime.
Fields
Prune
Prune old native runtimes from the cache.
Fields
Status
Show local model status on a running mesh-llm instance.
Bootstrap
Show the local-only owner-control bootstrap policy for a running mesh-llm instance.
Fields
GetConfig
Fetch config from a remote owner-control endpoint through the local management API.
Fields
ScanRefresh
Scan and refresh inventory on a remote owner-control endpoint.
Fields
LoadModel
Load a model on a remote node through owner-control.
Fields
UnloadModel
Unload a model on a remote node through owner-control.
Fields
EnsureModel
Ensure a model is loaded on a remote node through owner-control.
Fields
DrainModel
Drain and unload a model on a remote node through owner-control.
Fields
RefreshInventory
Refresh local inventory on a remote owner-control endpoint through the local management API.
Fields
ApplyConfig
Apply config to a remote owner-control endpoint through the local management API.
Fields
Load
Load a local model into a running mesh-llm instance.
Fields
Unload
Unload a local model from a running mesh-llm instance.
Fields
Guardrails
Set mesh guardrail mode on running Skippy-backed models without restart.